@@ -4,7 +4,6 @@ import subprocess
 from typing import List
 from pathlib import Path
 
-# from .ADict import ADict
 from zxvcv.util.Path import context_cwd
 
 log = logging.getLogger(__name__)
@@ -18,7 +17,7 @@ class Executable():
         cmd_output = None
         with context_cwd(workplace):
             cmd_output = subprocess.run(
-                [cls._EXE] + cmd,
+                [cls._EXE] + cmd if cls._EXE else cmd,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE
             )
